const fn flip(op: BinOpKind) -> BinOpKindExpand description
Returns the equivalent operator after swapping left and right operands.
e.g. const < var rewritten as var > const needs Gt.
const fn flip(op: BinOpKind) -> BinOpKindReturns the equivalent operator after swapping left and right operands.
e.g. const < var rewritten as var > const needs Gt.