fn is_boundary_composition(l: &Comparison, r: &Comparison) -> boolExpand description
True when two comparisons over the same operand together cover its whole range.
fn is_boundary_composition(l: &Comparison, r: &Comparison) -> boolTrue when two comparisons over the same operand together cover its whole range.