split_comparison

Function split_comparison 

fn split_comparison<'gcx>(
    expr: &'gcx Expr<'gcx>,
) -> Option<(&'gcx Expr<'gcx>, (bool, U256), BinOpKind)>
A relational/equality comparison between an operand and a constant, normalized to operand <op> const (the operator is flipped when the constant is on the left).