fn is_boundary_composition(left: &Comparison, right: &Comparison) -> boolExpand description
Returns true for boundary comparisons whose union covers the complete integer type range.
fn is_boundary_composition(left: &Comparison, right: &Comparison) -> boolReturns true for boundary comparisons whose union covers the complete integer type range.